---
title: Typography
layout: home
---


# Typography
Documentation and examples for Inkline typography, including global settings, headings, body text, lists, and more.
{: .lead }

## Headings
All HTML headings, `<h1>` through `<h6>`, are available.

<h1>h1. Inkline Heading</h1>
<h2>h2. Inkline Heading</h2>
<h3>h3. Inkline Heading</h3>
<h4>h4. Inkline Heading</h4>
<h5>h5. Inkline Heading</h5>
<h6>h6. Inkline Heading</h6>

~~~
<h1>h1. Inkline Heading</h1>
<h2>h2. Inkline Heading</h2>
<h3>h3. Inkline Heading</h3>
<h4>h4. Inkline Heading</h4>
<h5>h5. Inkline Heading</h5>
<h6>h6. Inkline Heading</h6>
~~~


<p class="h1">h1. Inkline Heading</p>
<p class="h2">h2. Inkline Heading</p>
<p class="h3">h3. Inkline Heading</p>
<p class="h4">h4. Inkline Heading</p>
<p class="h5">h5. Inkline Heading</p>
<p class="h6">h6. Inkline Heading</p>

~~~
<p class="h1">h1. Inkline Heading</p>
<p class="h2">h2. Inkline Heading</p>
<p class="h3">h3. Inkline Heading</p>
<p class="h4">h4. Inkline Heading</p>
<p class="h5">h5. Inkline Heading</p>
<p class="h6">h6. Inkline Heading</p>
~~~


## Customizing headings-font-size
Use the included utility classes to create a small secondary heading.

<h3>Inkline Heading <small class="_text-muted">With faded secondary text</small></h3>

~~~
<h3>
  Inkline Heading
  <small class="_text-muted">With faded secondary text</small>
</h3>
~~~


## Display Headings
Traditional heading elements are designed to work best in the meat of your page content. When you need a heading to stand out, consider using a display heading—a larger, slightly more opinionated heading style.

<h1 class="d1">d1. Display Heading</h1>
<h1 class="d2">d2. Display Heading</h1>
<h1 class="d3">d3. Display Heading</h1>
<h1 class="d4">d4. Display Heading</h1>
<h1 class="d5">d5. Display Heading</h1>
<h1 class="d6">d6. Display Heading</h1>

~~~
<h1 class="d1">d1. Display Heading</p>
<h1 class="d2">d2. Display Heading</p>
<h1 class="d3">d3. Display Heading</p>
<h1 class="d4">d4. Display Heading</p>
<h1 class="d5">d5. Display Heading</p>
<h1 class="d6">d6. Display Heading</p>
~~~


## Lead
Make a paragraph stand out by adding `.lead`

<p class="lead">
  Vivamus sagittis lacus vel augue laoreet rutrum faucibus dolor auctor. Duis mollis, est non commodo luctus.
</p>

~~~
<p class="lead">
  Vivamus sagittis lacus vel augue laoreet rutrum faucibus dolor auctor. Duis mollis, est non commodo luctus.
</p>
~~~


## Inline text elements
Styling for common inline HTML5 elements.

<p>You can use the mark tag to <mark>highlight</mark> text.</p>
<p><del>This line of text is meant to be treated as deleted text.</del></p>
<p><s>This line of text is meant to be treated as no longer accurate.</s></p>
<p><ins>This line of text is meant to be treated as an addition to the document.</ins></p>
<p><u>This line of text will render as underlined</u></p>
<p><small>This line of text is meant to be treated as fine print.</small></p>
<p><strong>This line rendered as bold text.</strong></p>
<p><em>This line rendered as italicized text.</em></p>

~~~
<p>You can use the mark tag to <mark>highlight</mark> text.</p>
<p><del>This line of text is meant to be treated as deleted text.</del></p>
<p><s>This line of text is meant to be treated as no longer accurate.</s></p>
<p><ins>This line of text is meant to be treated as an addition to the document.</ins></p>
<p><u>This line of text will render as underlined</u></p>
<p><small>This line of text is meant to be treated as fine print.</small></p>
<p><strong>This line rendered as bold text.</strong></p>
<p><em>This line rendered as italicized text.</em></p>
~~~


## Abbreviations
Stylized implementation of HTML’s `<abbr>` element for abbreviations and  acronyms to show the expanded version on hover. Abbreviations have a default underline and gain a help cursor to provide additional context on hover and to users of assistive technologies.

The word <abbr title="Address">addr</abbr> is abbreviated.</p>

~~~
<p>The word <abbr title="Address">addr</abbr> is abbreviated.</p>
~~~


## Blockquotes
For quoting blocks of content from another source within your document. Wrap `<blockquote>` around any HTML as the quote.

<blockquote class="blockquote -left -bordered">
  <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.</p>
  <footer>
     Someone famous in
    <cite title="Source Title">Source Title</cite>
  </footer>
</blockquote>

<blockquote class="blockquote -center">
  <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.</p>
  <footer>
     Someone famous in
    <cite title="Source Title">Source Title</cite>
  </footer>
</blockquote>

<blockquote class="blockquote -right -bordered">
  <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.</p>
  <footer>
     Someone famous in
    <cite title="Source Title">Source Title</cite>
  </footer>
</blockquote>

~~~
<blockquote class="blockquote -left -bordered">
  <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p>
  <footer>Someone famous in <cite title="Source Title">Source Title</cite></footer>
</blockquote>

<blockquote class="blockquote -center">
  <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p>
  <footer>Someone famous in <cite title="Source Title">Source Title</cite></footer>
</blockquote>

<blockquote class="blockquote -right -bordered">
  <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p>
  <footer>Someone famous in <cite title="Source Title">Source Title</cite></footer>
</blockquote>
~~~


## Lists
### Unstyled
Remove the default `list-style` and left margin on list items (immediate children only). This only applies to immediate children list items, meaning you will need to add the class for any nested lists as well.

<ul class="list -unstyled">
  <li>Lorem ipsum dolor sit amet</li>
  <li>Consectetur adipiscing elit</li>
  <li>Integer molestie lorem at massa</li>
  <li>Facilisis in pretium nisl aliquet</li>
  <li>Nulla volutpat aliquam velit
    <ul>
      <li>Phasellus iaculis neque</li>
      <li>Purus sodales ultricies</li>
      <li>Vestibulum laoreet porttitor sem</li>
      <li>Ac tristique libero volutpat at</li>
    </ul>
  </li>
  <li>Faucibus porta lacus fringilla vel</li>
  <li>Aenean sit amet erat nunc</li>
  <li>Eget porttitor lorem</li>
</ul>

~~~
<ul class="list -unstyled">
  <li>Lorem ipsum dolor sit amet</li>
  <li>Consectetur adipiscing elit</li>
  <li>Integer molestie lorem at massa</li>
  <li>Facilisis in pretium nisl aliquet</li>
  <li>Nulla volutpat aliquam velit
    <ul>
      <li>Phasellus iaculis neque</li>
      <li>Purus sodales ultricies</li>
      <li>Vestibulum laoreet porttitor sem</li>
      <li>Ac tristique libero volutpat at</li>
    </ul>
  </li>
  <li>Faucibus porta lacus fringilla vel</li>
  <li>Aenean sit amet erat nunc</li>
  <li>Eget porttitor lorem</li>
</ul>
~~~

### Inline
Remove a list’s bullets and apply some light `margin` using the `.-inline` class.

<ul class="list -inline">
  <li>Lorem ipsum</li>
  <li>Consectetur adipiscing</li>
  <li>Integer molestie</li>
</ul>

~~~
<ul class="list -inline">
  <li>Lorem ipsum</li>
  <li>Consectetur adipiscing</li>
  <li>Integer molestie</li>
</ul>
~~~

### Description
Align terms and descriptions horizontally by using our grid system’s predefined classes (or semantic mixins). For longer terms, you can optionally add a `.text-truncate` class to truncate the text with an ellipsis.

<dl class="row">
  <dt class="col -sm-3">Description title</dt>
  <dd class="col -sm-9">Lorem ipsum dolor sit amet, consectetur adipisicing elit.</dd>
  <dt class="col -sm-3">Description title</dt>
  <dd class="col -sm-9">Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</dd>
  <dt class="col -sm-3">Description title</dt>
  <dd class="col -sm-9">Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. </dd>
  <dt class="col -sm-3">Description title</dt>
  <dd class="col -sm-9">Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. </dd>
</dl>

~~~
<dl class="row">
  <dt class="col -sm-3">Description title</dt>
  <dd class="col -sm-9">Lorem ipsum dolor sit amet, consectetur adipisicing elit.</dd>
  <dt class="col -sm-3">Description title</dt>
  <dd class="col -sm-9">Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</dd>
  <dt class="col -sm-3">Description title</dt>
  <dd class="col -sm-9">Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.</dd>
  <dt class="col -sm-3">Description title</dt>
  <dd class="col -sm-9">Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</dd>
</dl>
~~~
